pub struct ExecutionTrace {
pub kind: String,
pub culist_id: u64,
pub duration_ns: u64,
pub wall_span_ns: u64,
pub excluded_intervals: u32,
pub residual_before_ns: Option<u64>,
pub intervals: Vec<ExecutionInterval>,
}Fields
kind: Stringculist_id: u64duration_ns: u64Sum of recorded process intervals in this CopperList.
wall_span_ns: u64Wall-clock span from the first through last retained interval.
excluded_intervals: u32Message slots carrying timestamps outside the current execution cluster.
residual_before_ns: Option<u64>intervals: Vec<ExecutionInterval>Trait Implementations
Sourceimpl Clone for ExecutionTrace
impl Clone for ExecutionTrace
Sourcefn clone(&self) -> ExecutionTrace
fn clone(&self) -> ExecutionTrace
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecutionTrace
impl Debug for ExecutionTrace
Sourceimpl<'de> Deserialize<'de> for ExecutionTrace
impl<'de> Deserialize<'de> for ExecutionTrace
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more